..
    This file is part of Python Client Library for STAC.
    Copyright (C) 2019-2021 INPE.

    Python Client Library for STAC is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


.. include:: readme.rst

.. toctree::
    :hidden:

    readme

.. toctree::
    :maxdepth: 2
    :caption: Documentation

    contributing
    API Reference <api/stac/index>

.. toctree::
    :maxdepth: 1
    :caption: Additional Notes

    history
    license
